#
# spec file for package librabbitmq
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012-2015 Remi Collet
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%global gh_commit   77e3805d1662034339c3c19bcdaaa62a56c1fa7e
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    alanxz
%global gh_project  rabbitmq-c
%global libname     librabbitmq
%global soname      4

Name:           %{libname}%{soname}
Version:        0.9.0
Release:        lp150.3.1
Summary:        Client library for AMQP
License:        MIT
Group:          Productivity/Networking/Other
Url:            https://github.com/alanxz/rabbitmq-c
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}.tar.gz
Patch0:         rabbitmq-c-remove_failing_rest-0.9.0.patch
BuildRequires:  cmake > 2.8
BuildRequires:  openssl-devel
BuildRequires:  gcc
# For tools
BuildRequires:  popt-devel
# For man page
BuildRequires:  xmlto

%description
This is a C-language AMQP client library for use with AMQP servers
speaking protocol versions 0-9-1.

%package -n %{libname}-devel
Summary:        Header files and development libraries for %{name}
# FIXME: use correct group, see "https://en.opensuse.org/openSUSE:Package_group_guidelines"
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n %{libname}-devel
This package contains the header files and development libraries
for %{name}.

%package -n %{libname}-tools
Summary:        Example tools built using the librabbitmq package
# FIXME: use correct group, see "https://en.opensuse.org/openSUSE:Package_group_guidelines"
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}

%description -n %{libname}-tools
This package contains example tools built using %{name}.

It provides:
amqp-consume        Consume messages from a queue on an AMQP server
amqp-declare-queue  Declare a queue on an AMQP server
amqp-delete-queue   Delete a queue from an AMQP server
amqp-get            Get a message from a queue on an AMQP server
amqp-publish        Publish a message on an AMQP server

%prep
%setup -q -n %{gh_project}-%{version}
%patch0 -p1

# Copy sources to be included in -devel docs.
cp -pr examples Examples


%build
# static lib required for tests
%cmake \
  -DBUILD_TOOLS_DOCS:BOOL=ON \
  -DBUILD_STATIC_LIBS:BOOL=ON

make %{?_smp_mflags}

%install
cd build
make install %{?_smp_mflags} DESTDIR=%{buildroot}

rm %{buildroot}%{_libdir}/%{libname}.a

%check
: check .pc is usable
grep @ %{buildroot}%{_libdir}/pkgconfig/librabbitmq.pc && exit 1

cd build
: upstream tests
make %{?_smp_mflags} test


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc LICENSE-MIT
%{_libdir}/%{libname}.so.%{soname}*

%files -n %{libname}-devel
%defattr(-,root,root)
%doc AUTHORS THANKS TODO *.md
%doc Examples
%{_libdir}/%{libname}.so
%{_includedir}/amqp*
%{_libdir}/pkgconfig/%{libname}.pc

%files -n %{libname}-tools
%defattr(-,root,root)
%{_bindir}/amqp-*
%{_mandir}/man1/amqp-*.1*
%{_mandir}/man7/librabbitmq-tools.7*

%changelog
* Mon May 28 2018 tuukka.pasanen@ilmi.fi
- Update to version 0.9.0
  * amqp-publish: added support for specifying headers via the -H flag
  * Add support for specifying timeout for amqp_login calls via
  * amqp_set_handshake_timeout
  * Add support for specifying timeouts in RPC-style AMQP methods via
  * amqp_set_rpc_timeout
  * Add define for AMQP_DEFAULT_VHOST
  * Support for SSL SNI
  * Support for OpenSSL v1.1.0
- Changed:
  * rabbitmq-c now requires Windows Vista or better
  * rabbitmq-c enables TCP keep-alive by default on platforms that support it
  * dropped support for compiling rabbitmq-c without threading support
  * OpenSSL is no longer un-intialized automatically by default. OpenSSL can be
    explicitly initialized by calling amqp_initialize_ssl_library and
    uninitialized by calling amqp_uninitialize_ssl_library.
- Fixed:
  * Correct bugs in processing of --url flag in tools (#364).
  * Improve documentation on AMQP_SASL_METHOD_EXTERNAL (#349)
  * Improve support for compiling under mingw-w64
  * Better support for handing SIGPIPE on Linux over SSL (#401)
  * Improve publish performance on Linux by not specifying MSG_MORE on last part
    of message.
  * Fix connection logic where multiple hostnames won't be tried if
    connection to doesn't fail immediately (#430)
- Removed:
  * autotools build system has been removed
  * many duplicate amqps_* examples, they did not add a lot of value
